==> horizon_13.0.3.orig.tar.gz: horizon-13.0.3/horizon/test/urls.py <==
# Copyright 2012 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# All Rights Reserved.
#
# Copyright 2012 Nebula, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
URL patterns for testing Horizon views.
"""

from django.conf.urls import include
from django.conf.urls import url
from django.contrib.auth import views
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.views.generic import TemplateView

import horizon
from horizon.test.jasmine import jasmine


urlpatterns = [
    url(r'', include(horizon.urls)),
    url(r"auth/login/", views.login, {'template_name': "auth/login.html"},
        name='login'),
    url(r'auth/', include('django.contrib.auth.urls')),
    url(r'^jasmine/.*?$', jasmine.dispatcher),
    url(r'^jasmine-legacy/$',
        TemplateView.as_view(
            template_name="horizon/jasmine/jasmine_legacy.html"),
        name='jasmine_tests'),
]

urlpatterns += staticfiles_urlpatterns()

==> horizon_14.1.0.orig.tar.gz: horizon-14.1.0/horizon/test/urls.py <==
# Copyright 2012 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# All Rights Reserved.
#
# Copyright 2012 Nebula, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
URL patterns for testing Horizon views.
"""

from django.conf.urls import include
from django.conf.urls import url
from django.contrib.auth import views
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.views.generic import TemplateView

import horizon
import horizon.base
from horizon.test.jasmine import jasmine


urlpatterns = [
    url(r'', horizon.base._wrapped_include(horizon.urls)),
    url(r"auth/login/", views.login, {'template_name': "auth/login.html"},
        name='login'),
    url(r'auth/', include('django.contrib.auth.urls')),
    url(r'^jasmine/.*?$', jasmine.dispatcher),
    url(r'^jasmine-legacy/$',
        TemplateView.as_view(
            template_name="horizon/jasmine/jasmine_legacy.html"),
        name='jasmine_tests'),
]

urlpatterns += staticfiles_urlpatterns()
